# ****** Metric length conversion ******

#centimeters to millimeters
def centimeters_to_millimeters(centimeter):
    return centimeter * 10

#decimeters to centimeters
def decimeters_to_centimeters(decimeter):
    return decimeter * 10


#meters to centimeters
def meters_to_centimeters(meter):
    return meter * 100


#meters to decimeters
def meters_to_decimeters(meter):
    return meter * 10


#kilometers to meters
def kilometers_to_meters (kilometer):
    return kilometer * 1000


# ****** Metric area conversion ******

#square centimeters to square millimeters
def squareCentimeters_to_squareMillimeters (squareCentimeter):
    return sqmillimeters * 100


#square meters to square centimeters
def squareMeters_to_squareCentimeters (sqmeter):
    return sqmeter * 10000


#hectares to square meters
def hectares_to_squareMeters(hectare):
    return hectare * 10000


# square kilometers to hectares
def squareMeters_to_hectares(sqkilometer):
    return sqkilometer * 100

#square kilometers to square meters
def squareKilometers_to_squareMeters(sqkilometer):
    return sqkilometer * 1000000


# ****** Metric volume conversion ******

#cubic centimeters to cubic millimeter
def cubicCentimeters_to_cubicMillimeters(cubicCentimeter):
    return cubicCentimeter * 1000

#cubic decimeters to cubic centimeter
def cubicDecimeters_to_cubicCentimeters(cubicDecimeter):
    return cubicDecimeter * 1000

#cubic meters to cubic centimeter
def cubicMeters_to_cubicCentimeters (cubicMeter):
    return cubicMeter * 1000000

#cubic meters to cubic decimeter
def cubicMeters_to_cubicDecimeters(cubicMeter):
    return cubicMeter * 1000



# ****** Metric weight conversion ******

#grams to milligrams
def grams_to_milligrams(gram):
    return gram * 1000


#decagrams to grams
def decagrams_to_grams(decagram):
    return decagram * 10

#kilograms to grams
def kilograms_to_grams(kilogram):
    return kilogram * 1000

#tonnes to kilogram
def tonnes_to_kilograms(tonne):
    return tonne * 1000

#gigagrams to megagram 
def gigagrams_to_megagrams(gigagram):
    return gigagram * 1000


# ****** Metric liquid conversion ******

#centiliters to milliliters
def centiliters_to_milliliters(centiliter):
    return centiliter * 10


#deciliters to centiliters
def deciliters_to_centiliters(deciliter):
    return deciliter * 10


#liters to milliliters
def liters_to_milliliters(liter):
    return liter * 1000


#liters to deciliters
def liters_to_deciliters(liter):
    return liter * 10


#kiloliters to liters
def kiloliters_to_liters(kiloliter):
    return kiloliter * 1000



# ****** Byte conversion ******

#byte to bits
def bytes_to_bit(bytes):
    return bytes * 8


#kilobyte to bytes
def kilobyte_to_byte(kilobytes):
    return kilobytes * 1024


#megabyte to kilobytes
def megabyte_to_kilobytes(megabytes):
    return megabytes * 1024


#gigabyte to megabytes
def gigabyte_to_megabytes(gigabyte):
    return gigabyte * 1024


#terabyte to gigabytes
def terabytes_to_gigabyte(terabytes):
    return terabytes * 1024


#petabyte to terabytes
def petabytes_to_terabyte(petabytes):
    return petabytes * 1024


#exabyte to petabytes
def exabyte_to_petabytes(exabyte):
    return exabyte * 1024


#zettabyte to exabytes
def zettabyte_to_exabytes(zettabyte):
    return zettabyte * 1024


#yottabyte to zettabytes
def yottabyte_to_zettabytes(yottabyte):
    return yottabyte * 1024

